aboutsummaryrefslogtreecommitdiff
path: root/sys/kern
diff options
context:
space:
mode:
Diffstat (limited to 'sys/kern')
-rw-r--r--sys/kern/init_main.c10
-rw-r--r--sys/kern/kern_panic.c4
-rw-r--r--sys/kern/kern_syslog.c4
-rw-r--r--sys/kern/kern_timer.c6
-rw-r--r--sys/kern/subr_tty.c4
-rw-r--r--sys/kern/tty.c6
6 files changed, 17 insertions, 17 deletions
diff --git a/sys/kern/kern_panic.c b/sys/kern/kern_panic.c
index 3d97abb..951c969 100644
--- a/sys/kern/kern_panic.c
+++ b/sys/kern/kern_panic.c
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 2023 Ian Marco Moffett and the VegaOS team.
+ * Copyright (c) 2023 Ian Marco Moffett and the Osmora Team.
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
@@ -10,7 +10,7 @@
* 2. Redistributions in binary form must reproduce the above copyright
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
- * 3. Neither the name of VegaOS nor the names of its
+ * 3. Neither the name of Hyra nor the names of its
* contributors may be used to endorse or promote products derived from
* this software without specific prior written permission.
*
diff --git a/sys/kern/kern_syslog.c b/sys/kern/kern_syslog.c
index f35e778..c4c6cd6 100644
--- a/sys/kern/kern_syslog.c
+++ b/sys/kern/kern_syslog.c
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 2023 Ian Marco Moffett and the VegaOS team.
+ * Copyright (c) 2023 Ian Marco Moffett and the Osmora Team.
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
@@ -10,7 +10,7 @@
* 2. Redistributions in binary form must reproduce the above copyright
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
- * 3. Neither the name of VegaOS nor the names of its
+ * 3. Neither the name of Hyra nor the names of its
* contributors may be used to endorse or promote products derived from
* this software without specific prior written permission.
*
diff --git a/sys/kern/kern_timer.c b/sys/kern/kern_timer.c
index fab06ce..b2967fc 100644
--- a/sys/kern/kern_timer.c
+++ b/sys/kern/kern_timer.c
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 2023 Ian Marco Moffett and the VegaOS team.
+ * Copyright (c) 2023 Ian Marco Moffett and the Osmora Team.
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
@@ -10,7 +10,7 @@
* 2. Redistributions in binary form must reproduce the above copyright
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
- * 3. Neither the name of VegaOS nor the names of its
+ * 3. Neither the name of Hyra nor the names of its
* contributors may be used to endorse or promote products derived from
* this software without specific prior written permission.
*
@@ -31,7 +31,7 @@
/*
* When a timer on the machine has been registered
- * to the Vega kernel, they'll be added to the Vega timer
+ * to the Hyra kernel, they'll be added to the Hyra timer
* registry.
*/
static const struct timer *tmr_registry[TIMER_ID_COUNT] = { 0 };
diff --git a/sys/kern/subr_tty.c b/sys/kern/subr_tty.c
index 59540e3..2803680 100644
--- a/sys/kern/subr_tty.c
+++ b/sys/kern/subr_tty.c
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 2023 Ian Marco Moffett and the VegaOS team.
+ * Copyright (c) 2023 Ian Marco Moffett and the Osmora Team.
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
@@ -10,7 +10,7 @@
* 2. Redistributions in binary form must reproduce the above copyright
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
- * 3. Neither the name of VegaOS nor the names of its
+ * 3. Neither the name of Hyra nor the names of its
* contributors may be used to endorse or promote products derived from
* this software without specific prior written permission.
*
diff --git a/sys/kern/init_main.c b/sys/kern/init_main.c
index d0b792f..e4cc524 100644
--- a/sys/kern/init_main.c
+++ b/sys/kern/init_main.c
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 2023 Ian Marco Moffett and the VegaOS team.
+ * Copyright (c) 2023 Ian Marco Moffett and the Osmora Team.
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
@@ -10,7 +10,7 @@
* 2. Redistributions in binary form must reproduce the above copyright
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. Neither the name of VegaOS nor the names of its
* contributors may be used to endorse or promote products derived from
* this software without specific prior written permission.
*
@@ -38,8 +38,8 @@
#include <logo.h>
__MODULE_NAME("init_main");
-__KERNEL_META("$Vega$: init_main.c, Ian Marco Moffett, "
- "Where the Vega kernel first starts up");
+__KERNEL_META("$Hyra$: init_main.c, Ian Marco Moffett, "
+ "Where the Hyra kernel first starts up");
static inline void
log_timer(const char *purpose, tmrr_status_t s, const struct timer *tmr)
@@ -77,7 +77,7 @@ main(void)
syslog_init();
PRINT_LOGO();
- kprintf("Vega/%s v%s: %s (%s)\n",
+ kprintf("Hyra/%s v%s: %s (%s)\n",
VEGA_ARCH, VEGA_VERSION, VEGA_BUILDDATE,
VEGA_BUILDBRANCH);
@@ -10,7 +10,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
- * 3. Neither the name of VegaOS nor the names of its
+ * 3. Neither the name of Hyra nor the names of its
* contributors may be used to endorse or promote products derived from
* this software without specific prior written permission.
diff --git a/sys/kern/tty.c b/sys/kern/tty.c
index 1519ff3..bc55be5 100644
--- a/sys/kern/tty.c
+++ b/sys/kern/tty.c
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 2023 Ian Marco Moffett and the VegaOS team.
+ * Copyright (c) 2023 Ian Marco Moffett and the Osmora Team.
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
@@ -10,7 +10,7 @@
* 2. Redistributions in binary form must reproduce the above copyright
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. Neither the name of VegaOS nor the names of its
* contributors may be used to endorse or promote products derived from
* this software without specific prior written permission.
*
@@ -46,7 +46,7 @@
#define CURSOR_WIDTH FONT_WIDTH
#define CURSOR_HEIGHT FONT_HEIGHT
-__KERNEL_META("$Vega$: tty.c, Ian Marco Moffett, "
+__KERNEL_META("$Hyra$: tty.c, Ian Marco Moffett, "
"Core TTY implementation");
/* List of attached TTYs */
@@ -10,7 +10,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
- * 3. Neither the name of VegaOS nor the names of its
+ * 3. Neither the name of Hyra nor the names of its
* contributors may be used to endorse or promote products derived from
* this software without specific prior written permission.